
.. image:: https://travis-ci.org/bnzk/django-formfieldstash.svg
    :target: https://travis-ci.org/bnzk/django-formfieldstash
.. image:: https://img.shields.io/pypi/v/django-formfieldstash.svg
    :target: https://pypi.python.org/pypi/django-formfieldstash/
.. image:: https://img.shields.io/pypi/l/django-formfieldstash.svg
    :target: https://pypi.python.org/pypi/django-formfieldstash/

show/hide modelform fields, depending on current value of a dropdown in the form. without page reload.
this is a pure javascript solution, using a modeladminmixin and/or Widget(attrs=stash_attr_helper(stash_config) approach.

Development and Docs on `<https://github.com/bnzk/django-formfieldstash/>`_
